# Python module that reads the output files produced by
# parabolic_equation.x or hyperbolic_equation.x
# into a vector and a matrix of data for subsequent plots.
# The script puts all the variables into a dictionary.

import numpy as np   # Needs the function "loadtxt"

def read_params( teq ):
    """
    Function that reads the parameters of a run produced
    by parabolic_equation.x or hyperbolic_equation.x.
    Return value: a dictionary with the values of the
    parameters read from the file "input.data".
    The argument is 1 for parabolic runs and 2 for hyperbolic.
    Example:
    import read_data as rd
    par = rd.read_params( 1 )
    """

    data = {}
    fdata = open( "input.data", "r" )
    line = fdata.readline()
    data["Np"] = int( line )
    line = fdata.readline()
    data["dt"] = float( line )
    line = fdata.readline()
    data["Tend"] = float( line )
    line = fdata.readline()
    data["Tprint"] = float( line )
    if ( teq == 2 ):
        line = fdata.readline()
        data["c"] = float( line )
    line = fdata.readline()
    data["nu"] = float( line )
    line = fdata.readline()
    data["k"] = int( line )
    line = fdata.readline()
    if ( teq == 1 ):
        data["bct"] = int( line )
    else:
        data["teq"] = int( line )
    return data

def read_data( pars ):
    """
    Function that reads the outputs of a run produced
    by parabolic_equation.x or hyperbolic_equation.x.
    Return values:
    a vector with the grid-points x
    an array containing for each column the outputs
    of the simulation.
    Example:
    import read_data as rd
    pars = rd.read_params()
    x, f = rd.read_data( pars )
    """

    num_outs = int( pars["Tend"] / pars["Tprint"] ) + 1
    out_names = np.arange( 0, num_outs )
    f = np.ndarray( ( pars["Np"] - 1, num_outs ), dtype = np.float64 )
    for n in out_names:
        fname = 'out-' + str( n )
        x, var = np.loadtxt( fname, dtype = np.float64, unpack = True )
        f[:,n] = var
    return x, f
